<?xml version="1.0" encoding="utf-8" ?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" >
<xsl:output method="text" encoding="utf-8"/>

<!-- Your account number must be specified as a parameter to xsltproc! -->
<xsl:param name="myAccountNumber">EMPTY</xsl:param>

<!-- Status _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _

	     This transformation takes only twice as long as the ezxml version (~130 ms : ~60 ms),
	     but with the benefit that well-formed-ness is guaranteed!
      _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ -->
	
<!-- /context/accountInfoList/accountInfo/transactionList/transaction/purpose -->


<!-- The following strips spaces from all nodes -->
<xsl:strip-space elements="*" />


<!-- Scheme definitions for decimal numbers -->
<xsl:decimal-format name="de" decimal-separator="," grouping-separator="."/>

<!-- The following selects only a specific account -->
<xsl:template match="accountInfo">
	<xsl:if test="normalize-space(accountNumber) = $myAccountNumber">
		<xsl:apply-templates select="transactionList/transaction" />
	</xsl:if>
</xsl:template>

<!-- Proper formatting for the date -->
<xsl:template name="format_date">
	<xsl:param name="date"/>

	<xsl:value-of select="format-number(number(normalize-space($date/day)),'00')"/><xsl:text>.</xsl:text>
	<xsl:value-of select="format-number(number(normalize-space($date/month)),'00')"/><xsl:text>.</xsl:text>
	<xsl:value-of select="normalize-space($date/year)"/><xsl:text> </xsl:text> <!-- We assume here that the year is always given as a four-digit value! -->
</xsl:template>

<!-- The transaction value might be a fraction, which is why this needs some preparation to have output properly formatted -->
<xsl:template name="transaction_value">
	<xsl:param name="value"/>

	<xsl:choose>
		<xsl:when test="contains($value, '/')">
			<xsl:value-of select="format-number(number(substring-before($value,'/')) div number(substring-after($value,'/')),'#.##0,00','de')"/> 
		</xsl:when>
		<xsl:otherwise>
			<xsl:value-of select="format-number(number($value),'#.##0,00','de')"/>
		</xsl:otherwise>
	</xsl:choose>
	<xsl:text> </xsl:text>
</xsl:template>

<!-- Extract all relevant information in the right order for each transaction -->
<xsl:template match="transaction">
	<xsl:call-template name="format_date">
		<xsl:with-param name="date" select="valutaDate/date"/>
	</xsl:call-template>
	<xsl:call-template name="format_date">
		<xsl:with-param name="date" select="date/date"/>
	</xsl:call-template>
	<xsl:value-of select="normalize-space(remoteName)"/><xsl:text> </xsl:text>
	<xsl:value-of select="normalize-space(transactionText)"/><xsl:text> </xsl:text>
	<xsl:value-of select="normalize-space(purpose)"/><xsl:text> </xsl:text>

	<!-- We need to take care of the value, since it might be a fraction -->
	<xsl:call-template name="transaction_value">
		<xsl:with-param name="value" select="value/value"/>
	</xsl:call-template>
	
	<xsl:value-of select="normalize-space(value/currency)"/><xsl:text>&#10;</xsl:text>
</xsl:template>


<!-- Throw away residual entries: -->

<xsl:template match="accountNumber">
</xsl:template>

<xsl:template match="bankCode">
</xsl:template>

<xsl:template match="statusList">
</xsl:template>

<xsl:template match="notedTransactionList">
</xsl:template>

</xsl:stylesheet>
